/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.cdi.xml;

import javax.enterprise.inject.spi.Bean;
import javax.enterprise.inject.spi.BeanManager;

import org.apache.camel.CamelContext;

final class BeanManagerHelper {

    private BeanManagerHelper() {
    }

    static CamelContext getCamelContextById(BeanManager manager, String camelContextId) {
        Bean<?> bean = manager.resolve(manager.getBeans(camelContextId));
        return (CamelContext) manager.getReference(bean, CamelContext.class, manager.createCreationalContext(bean));
    }

    static CamelContext getDefaultCamelContext(BeanManager manager) {
        Bean<?> bean = manager.resolve(manager.getBeans(CamelContext.class));
        return (CamelContext) manager.getReference(bean, CamelContext.class, manager.createCreationalContext(bean));
    }
}
